Learn R Programming

quantchem (version 0.12-1)

anova.lmcal, anova.nlscal: ANOVA tests for calibration models

Description

This function performs ANOVA tests between fitted calibration models.

Usage

anova.lmcal(object, ...)
anova.nlscal(object, ...)

Arguments

object
an object of class 'lmcal' or 'nlscal'
...
additional arguments (ignored)

Value

  • A list of 'anova' objects:
  • mandelThe test between linear and quadratic fit
  • logmandelThe same test, between two log-log models
  • tableThe test between linear, quadratic, cubical and 4th order models without weighting
  • wtableThe test between linear, quadratic, cubical and 4th order models with weighting

Details

For 'lmcal' models this function performs four tests: two ANOVAs between linear and quadratic model, without and with log-log transform (first is mentioned in literature as Mandel's fitting test), and two ANOVAs comparing four polynomial models, weighted and unweighted. For 'nlscal' models two ANOVAs are performed - between asymptotic models without and with intercept term, and between three and four parameter logistic models.

See Also

lmcal, nlscal

Examples

Run this code
data(nitrate)
attach(nitrate)
fit = lmcal(conc,area)
anova(fit)
fit2 = nlscal(conc,area)
anova(fit2)

Run the code above in your browser using DataLab