Learn R Programming

quantchem (version 0.12-1)

ibuprofen, genisten, biochanin, pseudoephedrine, nitrate: Calibration data for several compounds

Description

A sample calibration data with two replicates for each standard.

Usage

data(ibuprofen)
data(genisten)
data(biochanin)
data(pseudoephedrine)
data(nitrate)

Arguments

source

The data was originally published by Kirkup and Mulholland (2004) to discuss various calibration models.

References

Kirkup, L., Mulholland, M. (2004). Comparison of linear and non-linear equations in univariate calibration. J. Chromatogr. A, 1029, 1-11.

Examples

Run this code
data(ibuprofen)
attach(ibuprofen)
fit = lmcal(conc,area)
summary(fit)
anova(fit)
par(mfrow=c(2,2))
plot(fit)

Run the code above in your browser using DataLab