Learn R Programming

quantchem (version 0.12-1)

predict.lmcal, predict.nlscal: Inverse predict concentration from given responses

Description

Inverse predict concentration from responses, using all fitted calibration models.

Usage

predict.lmcal(object, dataset, conf.int = 0.95, ...)
predict.nlscal(object, dataset, ...)

Arguments

object
an object of class 'lmcal' or 'nlscal', respectively
dataset
a vector of responses
conf.int
confidence intercal (only for lmcal)
...
additional arguments, currently ignored

Value

  • A list containing following elements. Each element is a list of concentration vectors, calculated from a model, with name referring to the model.
  • fittedConcentrations calculated by fitted model
  • upperUpper limit of confidence interval of inverse prediction
  • lowerLower limit of confidence interval of inverse prediction

Details

For linear models, the concentrations are calculated by inverse.predict(), which calls polyroot() on modified polynomial coefficients. For nonlinear models, concentrations are calculated with appropriate 'inverse' formulas.

See Also

lmcal, nlscal

Examples

Run this code
set.seed(1234)
x=rep(1:10,10)
y=jitter(sqrt(x))
fit=lmcal(x,y)
predict(fit,rnorm(10,mean=2,sd=0.1))

Run the code above in your browser using DataLab