Learn R Programming

quantchem (version 0.12-1)

summary.lmcal, summary.nlscal: Summarizing fitted calibration curves

Description

A 'summary' class for 'lmcal' and 'nlscal' objects.

Usage

summary.lmcal(object, sort.models = FALSE, ...)
summary.nlscal(object, sort.models = FALSE, ...)

Arguments

object
an object of class 'lmcal' or 'nlscal'
sort.models
should the tables be sorted by models (TRUE) or variables (FALSE).
...
additional arguments, currently ignored.

Value

  • A list, consisting of following items:
  • coefficientsEstimated coefficients, their standard error, significance (t) and p-value
  • residualsQuantiles of residuals and Shapiro-Wilk test of their normality
  • variancesQuantiles of variances (without transform, with log-log, and with Box-Cox on y) ond Bartlett test for therir heteroscedascity. Calculated only, if there are at least 2 replicates for each x
  • fitR-squared, adjusted R-squared, AIC, residual standard error, sum of squared residuals, sum of pure error and Lack-of-Fit ANOVA test
  • sensitivitysensitivity, limit of detection and quantitation, autocorrelation of residuals, Durbin-Watson test for autocorrelation

Details

The function performs summarizing of fitted calibration models and produces several tables (see below). The are printed in appropriate form, and their list is returned invisibly.

See Also

lmcal, nlscal

Examples

Run this code
set.seed(1234)
x=rep(1:8,5)
y=jitter(sqrt(x))
fit=lmcal(x,y)
fit
summary(fit)

Run the code above in your browser using DataLab