logmandelThe same test, between two log-log models
tableThe test between linear, quadratic, cubical and
4th order models without weighting
wtableThe test between linear, quadratic, cubical and
4th order models with weighting
Details
For 'lmcal' models this function performs four tests: two ANOVAs
between linear and quadratic model, without and with log-log transform
(first is mentioned in literature as Mandel's fitting test), and
two ANOVAs comparing four polynomial models, weighted and unweighted.
For 'nlscal' models two ANOVAs are performed - between asymptotic
models without and with intercept term, and between three and four
parameter logistic models.