an object of class 'lmcal' or 'nlscal', respectively
dataset
a vector of responses
conf.int
confidence intercal (only for lmcal)
...
additional arguments, currently ignored
Value
A list containing following elements. Each element is a list of concentration vectors,
calculated from a model, with name referring to the model.
fittedConcentrations calculated by fitted model
upperUpper limit of confidence interval of inverse prediction
lowerLower limit of confidence interval of inverse prediction
Details
For linear models, the concentrations are calculated by inverse.predict(), which
calls polyroot() on modified polynomial coefficients. For nonlinear models,
concentrations are calculated with appropriate 'inverse' formulas.